% script zprtz_tool

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press
%
% Please refer to the online manual for detailed usage instructions

% Set input parameters.

close all;

prompt={'Vp_1 (m/s)','Vs_1 (m/s)','\rho_1 (g/cm^3)','Vp_2 (m/s)','VS_2 (m/s)','\rho_2 (gm/cm^3)','incw (1=P, 2=S)','scwt (1-4)'};
name='Input for Zprtz';
numlines=1;
defaultanswer={'4000','2100','2.4','6000','3200','2.6','1','1'};
options.Resize='on';
options.WindowStyle='normal';
options.Interpreter='tex';
answer=inputdlg(prompt,name,numlines,defaultanswer,options);

Vp1 = str2double(answer(1));
Vs1 = str2double(answer(2));
rho1 = str2double(answer(3));
Vp2 = str2double(answer(4));
Vs2 = str2double(answer(5));
rho2 = str2double(answer(6));
incw = round(str2double(answer(7)));
scwt = round(str2double(answer(8)));

for i = 1:90;
    alpha = (i-1)*pi/180;
    [raa,ang] = zprtz(Vp1,Vp2,Vs1,Vs2,rho1,rho2,incw,alpha);
    rc(i) = raa(scwt);
    phs(i) = ang(scwt)*180/pi;
end

subplot(2,1,1), plot([0:89],rc,'LineWidth',2);
xlabel('Angle of incidence in degrees');
ylabel('R/T coefficient');
tstring = ['Vp_1 =',num2str(Vp1),' Vs_1=',num2str(Vs1),' \rho_1=',num2str(rho1),' Vp_2=',num2str(Vp2),' Vs_2=',num2str(Vs2),' \rho_2=',num2str(rho2),' incw=',num2str(incw),' scwt=',num2str(scwt)];
title(tstring);

subplot(2,1,2), plot([0:89],phs,'r','LineWidth',2);
xlabel('Angle of incidence in degrees');
ylabel('Phase angle in degrees');